\name{exhier}
\docType{data}
\alias{exhier}
\title{Example data set with 4 levels, one diploid and one haploid locus}
\description{}
\usage{
data(exhier)
}
\format{
\item{lev1}{outermost level}
\item{lev2}{level 2}
\item{lev3}{Level 3}
\item{lev4}{Level 4}
\item{diplo}{Diploid locus}
\item{haplo}{Haploid locus}

}

\examples{
data(exhier)
varcomp(exhier[,1:5])
varcomp(exhier[,c(1:4,6)],diploid=FALSE)

}
\keyword{datasets}

\eof
\name{g.stats}
\alias{g.stats}
\title{Calculates likelihood-ratio G-statistic on contingency table}
\description{Calculates the likelihood ratio G-statistic on a contingency table of alleles at one locus X sampling unit. The sampling unit could be any hierarchical level}
\usage{
g.stats(data,diploid=TRUE)}
\arguments{
\item{data}{a two-column data frame. The first column contains the sampling unit, the second the genotypes}
\item{diploid}{Whether the data are from diploid (default) organisms}
}
\value{
\item{obs}{Observed contingency table}
\item{exp}{Expected number of allelic observations}
\item{X.squared}{The chi-squared statistics, \eqn{\sum\frac{(O-E)^2}{E}}{Sum (O-E)^2/E}}
\item{g.stats}{The likelihood ratio statistics, \eqn{2 \sum(O \log(\frac{O}{E}))}{2 Sum(O Log(O/E))}}
 }
\references{
Goudet J., Raymond, M., DeMeeus, T. and Rousset F. (1996) Testing differentiation in diploid populations. Genetics. 144: 1933-1940

Goudet, J. (2004). A library for R to compute and test variance components and F-statistics.

Petit E., Balloux F. and Goudet J.(2001) Sex-biased dispersal in a migratory bat: A characterization using sex-specific demographic parameters. Evolution 55: 635-640. 

}
\author{Jerome Goudet,
DEE, UNIL, 
CH-1015
Lausanne
Switzerland 

\email{jerome.goudet@unil.ch}
}
\seealso{\code{\link{g.stats.glob}}.}
\examples{
data(gtrunchier)
attach(gtrunchier)
g.stats(data.frame(Patch,L21.V))
}
\keyword{univar}

\eof
\name{g.stats.glob}
\alias{g.stats.glob}
\title{Likelihood ratio G-statistic over loci}
\description{Calculates the likelihood ratio G-statistic on a contingency table of alleles at one locus X sampling unit, and sums this statistic over the loci provided. The sampling unit could be any hierarchical level (patch, locality, region,...). By default, diploid data are assumed}
\usage{
g.stats.glob(data,diploid=TRUE)
}
\arguments{
\item{data}{a data frame made of \kbd{nl+1} column, \kbd{nl} being the number of loci. The first column contains the sampling unit, the others the multi-locus genotype. Only complete multi-locus genotypes are kept for calculation}
\item{diploid}{Whether the data are from diploid (default) organisms}
}
\value{
\item{g.stats.l}{Per locus likelihood ratio statistic}
\item{g.stats}{Overall loci likelihood ratio statistic}
 }
\references{
Goudet J. (2004). A library for R to compute and test variance components and F-statistics. In Prep

Goudet J., Raymond, M., DeMeeus, T. and Rousset F. (1996) Testing differentiation in diploid populations. Genetics. 144: 1933-1940

Petit E., Balloux F. and Goudet J.(2001) Sex-biased dispersal in a migratory bat: A characterization using sex-specific demographic parameters. Evolution 55: 635-640. 
}
\author{Jerome Goudet,
DEE, UNIL, 
CH-1015
Lausanne
Switzerland 

\email{jerome.goudet@unil.ch}
}
\seealso{\code{\link{g.stats}}, \code{\link{samp.within}},\code{\link{samp.between}}.}
\examples{
data(gtrunchier)
attach(gtrunchier)
nperm<-99
nobs<-length(Patch)
gglobs.o<-vector(length=(nperm+1))
gglobs.p<-vector(length=(nperm+1))
gglobs.l<-vector(length=(nperm+1))

gglobs.o[nperm+1]<-g.stats.glob(data.frame(Patch,gtrunchier[,-c(1,2)]))$g.stats
gglobs.p[nperm+1]<-g.stats.glob(data.frame(Patch,gtrunchier[,-c(1,2)]))$g.stats
gglobs.l[nperm+1]<-g.stats.glob(data.frame(Locality,gtrunchier[,-c(1,2)]))$g.stats

for (i in 1:nperm) #careful, might take a while
{
  gglobs.o[i]<-g.stats.glob(data.frame(Patch,gtrunchier[sample(Patch),-c(1,2)]))$g.stats
  gglobs.p[i]<-g.stats.glob(data.frame(Patch,gtrunchier[samp.within(Locality),-c(1,2)]))$g.stats
  gglobs.l[i]<-g.stats.glob(data.frame(Locality,gtrunchier[samp.between(Patch),-c(1,2)]))$g.stats
}
#p-value of first test (among patches)
p.globs.o<-sum(gglobs.o>=gglobs.o[nperm+1])/(nperm+1) 

#p-value of second test (among patches within localities)
p.globs.p<-sum(gglobs.p>=gglobs.p[nperm+1])/(nperm+1) 

#p-value of third test (among localities)
p.globs.l<-sum(gglobs.l>=gglobs.l[nperm+1])/(nperm+1) 


#Are alleles associated at random among patches
p.globs.o 

#Are alleles associated at random among patches within localities?
#Tests differentiation among patches within localities
p.globs.p 

#Are alleles associated at random among localities, keeping patches as one unit?
#Tests differentiation among localities
p.globs.l 
}
\keyword{univar}

\eof
\name{genot2al}
\alias{genot2al}
\title{Separates diploid genotypes in its constituant alleles}
\description{
Separates the input vector of diploid genotypes in two vectors each containing one allele, and returns a vector of length \kbd{2*length(y)} with the second part being the second allele
}
\usage{
genot2al(y)
}
\arguments{
\item{y}{the diploid genotypes at one locus}
}
\value{
returns a vector of length \kbd{2*length(y)}, with the second half of the vector containing the second alleles}
\references{
Goudet J. (2004). A library for R to compute and test variance components and F-statistics. In Prep
}
\author{Jerome Goudet,
DEE, UNIL, 
CH-1015
Lausanne
Switzerland 

\email{jerome.goudet@unil.ch}
}
\seealso{\code{\link{varcomp}}.}
\examples{
data(gtrunchier)
genot2al(gtrunchier[,4])
}
\keyword{manip}

\eof
\name{gtrunchier}
\docType{data}
\alias{gtrunchier}
\title{Genotypes at 6 microsatellite loci of Galba truncatula from different patches in Western Switzerland}
\description{Data set consisting of the microsatellite genotypes of 370 Galba truncatula, a tiny freshwater snail, collecting from different localities and several patches within localities in Western Switzerland.}
\usage{
data(gtrunchier)
}
\format{
\item{Locality}{Identifier of the locality of origin}
\item{Patch}{Identifier of the patch of origin}
\item{L21.V}{Genotype at locus L21.V. For instance the first individual carries allele 2 and 2 at this locus \preformatted{gtrunchier\$L21.V[1]}}
\item{L37.J}{Genotype at locus L37.J}
\item{L20.B}{Genotype at locus L20.B}
\item{L29.V}{Genotype at locus L29.V}
\item{L36.B}{Genotype at locus L36.B}
\item{L16.J}{Genotype at locus L16.J}

}

\references{
Trouve S., L. Degen et al. (2000) Microsatellites in the hermaphroditic snail, Lymnaea truncatula, intermediate host of the liver fluke, Fasciola hepatica.Molecular Ecology 9: 1662-1664.

Trouve S., Degen L. and Goudet J. (2004) Ecological components and evolution of selfing in the freshwater snail Galba truncatula. Journal of Evolutionary Biology. In Press
}
\keyword{datasets}


\eof
\name{hierfstat}
\alias{hierfstat}
\title{General information on the hierfstat package}
\description{This package contains functions to estimate hierarchical F-statistics for any number of hierarchical levels using the method described in Yang (1998).  It also contains functions allowing to test the significance of population differentiation at any given level using the likelihood ratio G-statistic, showed previoulsly to be the most powerful statistic to test for differnetiation (Goudet etal, 1996) . The difficulty in a hierarchical design is to identify which units should be permutted. Functions \kbd{samp.within} and \kbd{samp.between} give permutations of a sequence that allows reordering of the observations in the original data frame. An exemple of application is given in the help page for function \kbd{g.stats.glob}.

}

\references{
Goudet J., Raymond, M., DeMeeus, T. and Rousset F. (1996) Testing differentiation in diploid populations. Genetics. 144: 1933-1940

Weir, B.S. (1996) Genetic Data Analysis II. Sinauer Associates.

Yang, R.C. (1998). Estimating hierarchical F-statistics. Evolution 52(4):950-956
}
\author{Jerome Goudet \email{jerome.goudet@unil.ch}}
\keyword{misc}

\eof
\name{prepdata}
\alias{prepdata}
\title{Sort and renumber and recode levels for the hierarchical analysis if necessary}
\description{Called by varcomp to rearrange data. Should not need to be called directly}
\usage{
prepdata(data)
}
\arguments{
\item{data}{takes as input the different factor from the outermost (e.g. region) to the innermost (e.g. individual). This function must be applied before transformation of genotypic to allelic data}
}
\value{
a reoredered,renumbered and sorted data frame 
 }
\references{
Goudet J. (2004). A library for R to compute and test variance components and F-statistics. In Prep
}
\seealso{\code{\link{varcomp}}.}
\examples{
f1<-rep(c("B","C","A"),each=10)
f2<-rep(c("d","i","f","g","h","e"),each=5)
prepdata(data.frame(loc=f1,patch=f2,ind=1:30))
}
\keyword{manip}

\eof
\name{read.fstat.data}
\alias{read.fstat.data}
\title{Reads data from a FSTAT file}
\description{Imports a \emph{FSTAT} data file into R, skipping the unecessary information. The data frame created is made of \kbd{nl+1} columns, \kbd{nl} being the number of loci. The first column corresponds to the Population identifier, the following columns contains the genotypes of the individuals.}
\usage{
read.fstat.data(filename,nloc,na.s="0")
}
\arguments{
\item{filename}{a file in the FSTAT format (\url{http://www.unil.ch/popgen/softwares/fstat.htm}):  The file must have the following format:

The first line contains 4 numbers: the number of samples, \kbd{np} , the number of loci, \kbd{nl}, the highest number used to label an allele, \kbd{nu}, and a 1 if the code for alleles is a one digit number (1-9), a 2 if code for alleles is a 2 digit number (01-99) or a 3 if code for alleles is a 3 digit number (001-999).  These 4 numbers need to be separated by any number of spaces. \emph{Actually, the function read.fstat.dat skips the first line. The info is just here to make sure that if you were to run the data set in fstat, it will work.}

The first line is immediately followed by \kbd{nl} lines, each containing the name of a locus, in the order they will appear in the rest of the file.

	On line \kbd{nl+2}, a series of numbers as follow:

	\preformatted{1     0102   0103   0101  0203          0      0303}

The first number identifies the sample to which the individual belongs, the second is the genotype of the individual at the first locus, coded with a 2 digits number for each allele, the third is the genotype at the second locus, until locus nl is entered (in the example above, \kbd{nl=6}).  Missing genotypes are encoded with 0.  Note that 0001 or 0100 are not a valid format, that is, both alleles at a locus have to be known, otherwise, the genotype is considered as missing.
No empty lines are needed between samples.  }
\item{nloc}{The number of loci}
\item{na.s}{The string that corresponds to the missing value. \emph{You should note have to change this}}
}

\value{
a data frame containing the desired data, in a format adequate to pass to \kbd{varcomp}
 }
\references{
Goudet J. (1995). FSTAT (Version 1.2): A computer program to calculate F- statistics. Journal of Heredity 86:485-486

Goudet J. (2004). A library for R to compute and test variance components and F-statistics. In Prep
}
\examples{
read.fstat.data(paste(.path.package("hierfstat"),"/data/diploid.dat",sep="",collapse=""),nloc=5)
}

\keyword{manip}

\eof
\name{samp.between}
\alias{samp.between}
\title{Shuffles a sequence among groups defined by the input vector}
\description{Used to generate a permutation of a sequence \kbd{1:length(lev)}. blocks of observations are permutted, according to the vector \kbd{lev} passed to the function.}
\usage{
samp.between(lev)
}
\arguments{
\item{lev}{a vector containing the groups to be permuted.}
}
\value{
a vector \kbd{1:length(lev)} (with blocks defined by data) randomly permuted. Usually, one passes the result to reorder observations in a data set in order to carry out permutation-based tests
 }
\references{
Goudet J. (2004). A library for R to compute and test variance components and F-statistics. In Prep
}

\author{Jerome Goudet,
DEE, UNIL, 
CH-1015
Lausanne
Switzerland 

\email{jerome.goudet@unil.ch}
}

\seealso{\code{\link{samp.within}}, \code{\link{g.stats.glob}}.}
\examples{
samp.between(rep(1:4,each=4))
#for an application see example in g.stats.glob
}
\keyword{manip}

\eof
\name{samp.between.within}
\alias{samp.between.within}
\title{Shuffles a sequence}
\description{Used to generate a permutation of a sequence \kbd{1:length(inner.lev)}. blocks of observations defined by \kbd{inner.lev} are permutted within blocks defined by \kbd{outer.lev}}
\usage{
samp.between.within(inner.lev, outer.lev)
}
\arguments{
\item{inner.lev}{a vector containing the groups to be permuted.}
\item{outer.lev}{a vector containing teh blocks within which observations are to be kept.}
}
\value{
a vector \kbd{1:length(lev)} (with blocks defined by data) randomly permuted. Usually, one passes the result to reorder observations in a data set in order to carry out permutation-based tests
 }

\seealso{\code{\link{test.between.within}}.}
\keyword{manip}

\eof
\name{samp.within}
\alias{samp.within}
\title{Shuffles a sequence within groups defined by the input vector}
\description{Used to generate a permutation of a sequence \kbd{1:length(lev)}. observations are permutted within blocks, according to the vector \kbd{lev} passed to the function.}
\usage{
samp.within(lev)
}
\arguments{
\item{lev}{a vector containing the group to which belongs the observations to be permuted.}
}
\value{
a vector \kbd{1:length(lev)} (with blocks defined by \preformatted{lev}) randomly permuted. Usually, one passes the result to reorder observations in a data set in order to carry out permutation-based tests.
 }
\references{
Goudet J. (2004). A library for R to compute and test variance components and F-statistics. In Prep
}
\author{Jerome Goudet,
DEE, UNIL, 
CH-1015
Lausanne
Switzerland 

\email{jerome.goudet@unil.ch}
}
\seealso{\code{\link{samp.between}},\code{\link{g.stats.glob}}.}
\examples{
samp.within(rep(1:4,each=4))
#for an application see example in g.stats.glob
}
\keyword{manip}

\eof
\name{test.between}
\alias{test.between}
\title{Tests the significance of the effect of test.lev on genetic differentiation}
\description{}
\usage{
test.between(data, test.lev, rand.unit, nperm, ...)
}
\arguments{
\item{data}{a data frame containing the genotypes for the different loci}
\item{test.lev}{A vector containing the units from which to construct the contingency tables}
\item{rand.unit}{A vector containing the assignment of each observation to the units to be permutted}
\item{nperm}{The number of permutations to carry out for the test}
\item{...}{Mainly here to allow passing \kbd{diploid=FALSE} if necessary}
}
\value{
\item{g.star}{A vector containing all the generated g-statistics, the last one beeing the observed}
\item{p.val}{The p-value associated with the test}
}
\author{Jerome Goudet \email{jerome.goudet@unil.ch}}
\examples{
data(gtrunchier)
attach(gtrunchier)
#test whether the locality level has a significant effect on genetic structuring
test.between(gtrunchier[,-c(1,2)],test.lev=Locality,rand.unit=Patch)
}
\keyword{nonparametric}

\eof
\name{test.between.within}
\alias{test.between.within}
\title{Tests the significance of the effect of test.lev on genetic differentiation}
\description{Tests, using permutations of \kbd{rand.unit} within units defined by the vector \kbd{within} the significance of the contingency tables allele X (levels of \kbd{test.lev})}
\usage{
test.between.within(data, within, test.lev, rand.unit, nperm, ...) 
}
\arguments{
\item{data}{a data frame containing the genotypes for the different loci}
\item{within}{A vector containing the units in which to keep the observations}
\item{test.lev}{A vector containing the units from which to construct the contingency tables}
\item{rand.unit}{A vector containing the assignment of each observation to the units to be permutted}
\item{nperm}{The number of permutations to carry out for the test}
\item{...}{Mainly here to allow passing \kbd{diploid=FALSE} if necessary}
}
\value{
\item{g.star}{A vector containing all the generated g-statistics, the last one beeing the observed}
\item{p.val}{The p-value associated with the test}
}
\author{Jerome Goudet \email{jerome.goudet@unil.ch}}
\examples{
data(yangex)
attach(yangex)
#tests for the effect of spop on genetic structure
test.between.within(data.frame(genot),within=pop,test=spop,rand=sspop)
}
\keyword{nonparametric}

\eof
\name{test.g}
\alias{test.g}
\title{Tests the significance of the effect of level on genetic differentiation}
\description{}
\usage{
test.g(data = data, level, nperm = 100,...)
}
\arguments{
\item{data}{a data frame containing the genotypes for the different loci}
\item{level}{A vector containing the assignment of each observation to its level}
\item{nperm}{The number of permutations to carry out for the test}
\item{...}{Mainly here to allow passing \kbd{diploid=FALSE} if necessary}
}
\value{
\item{g.star}{A vector containing all the generated g-statistics, the last one beeing the observed}
\item{p.val}{The p-value associated with the test}
}
\author{Jerome Goudet \email{jerome.goudet@unil.ch}}
\examples{
data(gtrunchier)
attach(gtrunchier)
test.g(gtrunchier[,-c(1,2)],Locality)
}
\keyword{nonparametric}

\eof
\name{test.within}
\alias{test.within}
\title{Tests the significance of the effect of inner.level on genetic differentiation within blocks defined by outer.level}
\description{}
\usage{
test.within(data, within, test.lev, nperm, ...)
}
\arguments{
\item{data}{a data frame containing the genotypes for the different loci}
\item{within}{A vector containing the units in which to keep the observations}
\item{test.lev}{A vector containing the units from which to construct the contingency tables}
\item{nperm}{The number of permutations to carry out for the test}
\item{...}{Mainly here to allow passing \kbd{diploid=FALSE} if necessary}
}
\value{
\item{g.star}{A vector containing all the generated g-statistics, the last one beeing the observed}
\item{p.val}{The p-value associated with the test}
}
\author{Jerome Goudet \email{jerome.goudet@unil.ch}}
\examples{
data(gtrunchier)
attach(gtrunchier)
#tests whether the patch level has a significant effect on genetic structure
test.within(gtrunchier[,-c(1,2)],within=Locality,test.lev=Patch)
}
\keyword{nonparametric}

\eof
\name{varcomp}
\alias{varcomp}
\title{Estimates variance components for each allele of a locus}
\description{Estimates variance components for each allele for a (fully) hierarchical random design defined by all but the last column of the data frame  \kbd{data}, the last column containing the genetic data to analyse. Columns for the hierarchical design should be given from the outermost to the innermost before the individual (e.g. continent, region, population, patch,...)}
\usage{
varcomp(data,diploid=TRUE)
}
\arguments{
\item{data}{a data frame that contains the different factors from the outermost (e.g. region)
to the innermost before the individual. the last column of the data frame 'data' contains the locus to analyse, which can be multiallelic. Missing data are allowed.}
\item{diploid}{a boolean stating whether the data come from diploid (TRUE=default) or haploid (FALSE) organisms}}
\value{
\item{df}{the degrees of freedom for each level}
\item{k}{the k matrix, the coefficients associated with the variance components}
\item{res}{the variance components for each allele}
\item{overall}{the variance components summed over alleles}
\item{F}{a matrix of hierarchical F-statistics type-coefficients
 with the first line corresponding to \eqn{F_{(n-1)/n}},\eqn{F_{(n-2)/n}}...\eqn{F_{i/n}} and
 the diagonal corresponding to \eqn{F_{(n-1)/n}}, \eqn{F_{(n-2)/(n-1)}},\eqn{F_{i/2}}}
}
\details{The format for genotypes is simply the code for the 2 alleles put one behind the other, without space in between. For instance if allele 1 at the locus has code \kbd{23} and allele 2 \kbd{39}, the genotype format is \kbd{2339}. 
}
\references{
Weir, B.S. (1996) Genetic Data Analysis II. Sinauer Associates.

Yang, R.C. (1998). Estimating hierarchical F-statistics. Evolution 52(4):950-956

Goudet, J. (2004). A library for R to compute and test variance components and F-statistics.
}
\author{Jerome Goudet,
DEE, UNIL, 
CH-1015
Lausanne
Switzerland 

\email{jerome.goudet@unil.ch}

\url{http://www.unil.ch/popgen/people/jerome.htm}
}
\seealso{\code{\link{varcomp.glob}}.}
\examples{
#load data set
data(gtrunchier)
attach(gtrunchier)
#
varcomp(data.frame(Locality,Patch,L21.V))
}
\keyword{univar}

\eof
\name{varcomp.glob}
\alias{varcomp.glob}
\title{Estimate variance components and hierarchical F-statistics over all loci}
\description{Return multilocus estimators of variance components and F-statistics}
\usage{
varcomp.glob(levels=levels,loci=loci,diploid=TRUE)
}
\arguments{
\item{levels}{a data frame containing the different levels (factors) from the outermost (e.g. region) to the innermost before the individual}
\item{loci}{a data frame containing the different loci}
\item{diploid}{Specify whether the data are coming from diploid or haploid organisms (diploid is the default)}
}
\value{
\item{loc}{The variance components for each locus}
\item{overall}{The variance components summed over all loci}
\item{F}{a matrix of hierarchical F-statistics type-coefficients
 with the first line corresponding to \eqn{F_{(n-1)/n}},\eqn{F_{(n-2)/n}}...\eqn{F_{i/n}} and
 the diagonal corresponding to \eqn{F_{(n-1)/n}}, \eqn{F_{(n-2)/(n-1)}},\eqn{F_{i/2}}}
 }
\references{
Weir, B.S. (1996) Genetic Data Analysis II. Sinauer Associates.

Yang, R.C. (1998). Estimating hierarchical F-statistics. Evolution 52(4):950-956

Goudet, J. (2004). A library for R to compute and test variance components and F-statistics. In prep
}
\author{Jerome Goudet
DEE, UNIL, 
CH-1015
Lausanne
Switzerland 

\email{jerome.goudet@unil.ch}
}

\seealso{\code{\link{varcomp}}.}
\examples{
#load data set
data(gtrunchier)
attach(gtrunchier)
varcomp.glob(data.frame(Locality,Patch),gtrunchier[,-c(1,2)])
}
\keyword{univar}

\eof
\name{yangex}
\docType{data}
\alias{yangex}
\title{Example data set from Yang (1998) appendix}
\description{Reproduce the example data set used in Yang's paper appendix. 
The genotype (column genot) is invented}
\usage{
data(exhier)
}
\format{
\item{pop}{outermost level}
\item{spop}{sub pop level}
\item{sspop}{sub sub pop level}
\item{genot}{dummy diploid genotype}

}
\references{
Yang, R.C. (1998). Estimating hierarchical F-statistics. Evolution 52(4):950-956
}

\examples{
data(yangex)
varcomp(yangex)
#the k matrix should be the same as matrix (A2) in Yang's appendix, p. 956
}
\keyword{datasets}

\eof
